@@ -3,7 +3,7 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = "1.00";
+our $VERSION = "1.0.1";
 
 use Class::Load qw(load_class);
 use Crypt::OpenSSL::PKCS12;
@@ -436,6 +436,7 @@ sub load {
   my $dataset_id = $args{dataset_id} // $self->{dataset_id};
   my $table_id = $args{table_id};
   my $data = $args{data};
+  my $async = $args{async} // 0;
 
   unless ($project_id) {
     warn "no project\n";
@@ -519,13 +520,17 @@ sub load {
     dataset_id => $dataset_id,
     talbe_id => $table_id,
     content => $content,
-    data => $data
+    data => $data,
+    async => $async
   );
   $self->{response} = $response;
 
   if (defined $response->{error}) {
     warn $response->{error}{message};
     return 0;
+  } elsif ($async) {
+    # return job_id if async is true.
+    return $response->{jobReference}{jobId};
   } elsif ($response->{status}{state} eq 'DONE') {
     if (defined $response->{status}{errors}) {
       foreach my $error (@{$response->{status}{errors}}) {
@@ -949,9 +954,22 @@ Google::BigQuery - Google BigQuery Client Library for Perl
       
     unlink $load_file;
 
+    # insert
+    my $values = [];
+    for (my $id = 101; $id <= 103; $id++) {
+      push @$values, { id => $id, name => "name-${id}" };
+    }
+    $bq->insert(
+      table_id => $table_id,
+      values => $values,
+    );
+
+    # The first time a streaming insert occurs, the streamed data is inaccessible for a warm-up period of up to two minutes.
+    sleep(120);
+
     # selectrow_array
     my ($count) = $bq->selectrow_array(query => "SELECT COUNT(*) FROM $table_id");
-    print $count, "\n";
+    print $count, "\n"; # 103
 
     # selectall_arrayref
     my $aref = $bq->selectall_arrayref(query => "SELECT * FROM $table_id ORDER BY id");
@@ -1177,7 +1195,7 @@ See details at https://cloud.google.com/bigquery/streaming-data-into-bigquery.
     project_id => $project_id,    # required if default project is not set
     dataset_id => $dataset_id,    # required if default project is not set
     table_id => $table_id,        # required
-    values => \%values,           # required
+    values => \@values,           # required
   );
 
 =item * selectrow_array
